%bcond_with tests

%global srcname cryptography
%global rust_arches x86_64 aarch64 ppc64le riscv64 loongarch64

Summary:        PyCA's cryptography library
Name:           python-%{srcname}
Version:        41.0.4
Release:        10%{?dist}
License:        ASL 2.0 or BSD
URL:            https://cryptography.io/en/latest/
Source0:        https://github.com/pyca/cryptography/archive/%{version}/%{srcname}-%{version}.tar.gz
# Fetched from crates.io by executing `cargo vendor` in %%{srcname}-%%{version}/src/rust
Source1:        cryptography-%{version}-vendor.tar.bz2

#upstream:https://github.com/pyca/cryptography/pull/9926/commits/66cb448876b1e95b637461d13560b970bae09e08
Patch0001:      fix-CVE-2023-49083.patch
#upstream:https://github.com/pyca/cryptography/pull/10423/commits/3e5fc0e30f708df624f28170bb8963b180ebf7e6
Patch0002:      fix-CVE-2024-26130.patch

BuildRequires:  gcc gnupg2 cargo rust rust-toolset
BuildRequires:  openssl-devel
BuildRequires:  python%{python3_pkgversion}-cffi >= 1.7
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-setuptools-rust >= 0.11.3
BuildRequires:  python%{python3_pkgversion}-six >= 1.4.1
%if %{with tests}
BuildRequires:  python%{python3_pkgversion}-hypothesis >= 1.11.4
BuildRequires:  python%{python3_pkgversion}-iso8601
BuildRequires:  python%{python3_pkgversion}-pretend
BuildRequires:  python%{python3_pkgversion}-pytest-xdist
BuildRequires:  python%{python3_pkgversion}-pytest >= 6.0
BuildRequires:  python%{python3_pkgversion}-pytest-benchmark
BuildRequires:  python%{python3_pkgversion}-pytest-subtests >= 0.3.2
BuildRequires:  python%{python3_pkgversion}-pytz
%endif
ExclusiveArch:  %{rust_arches}

%description
cryptography includes both high level recipes and low level interfaces to 
common cryptographic algorithms such as symmetric ciphers, message digests, 
and key derivation functions.

%package -n  python%{python3_pkgversion}-%{srcname}
Summary:        PyCA's cryptography library
Requires:       openssl-libs
Requires:       python%{python3_pkgversion}-six >= 1.4.1
Requires:       python%{python3_pkgversion}-cffi >= 1.7

%description -n python%{python3_pkgversion}-%{srcname}
cryptography includes both high level recipes and low level interfaces to 
common cryptographic algorithms such as symmetric ciphers, message digests, 
and key derivation functions.

%prep
%autosetup -p1 -n %{srcname}-%{version}
%cargo_prep -V 1

%build
export RUSTFLAGS="%build_rustflags"
%py3_build

%install
find . -name .keep -print -delete
%py3_install

%check
%if %{with tests}
PYTHONPATH=${PWD}/vectors:%{buildroot}%{python3_sitearch} \
    %{__python3} -m pytest
%endif

%files -n python%{python3_pkgversion}-%{srcname}
%license LICENSE LICENSE.APACHE LICENSE.BSD
%doc README.rst docs
%{python3_sitearch}/%{srcname}
%{python3_sitearch}/%{srcname}-%{version}-py*.egg-info

%changelog
* Mon Nov 04 2024 jackeyji <jackeyji@tencent.com> - 41.0.4-10
- [Type] bugfix
- [DESC] correct the source package path

* Mon Nov 04 2024 jackeyji <jackeyji@tencent.com> - 41.0.4-9
- [Type] other
- [DESC] update script for rpm-upgrade

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 41.0.4-8
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Thu Sep 19 2024 jackeyji <jackeyji@tencent.com> - 41.0.4-7
- [Type] security
- [DESC] fix CVE-2024-26130

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 41.0.4-6
- Rebuilt for loongarch release

* Thu Aug 01 2024 Rebuild Robot <rebot@opencloudos.org> - 41.0.4-5
- [Type] bugfix
- [DESC] Rebuilt for gcc

* Fri Jul 26 2024 jackeyji <jackeyji@tencent.com> - 41.0.4-4
- [Type] bugfix
- [DESC] adapt cargo_prep macro

* Tue Jun 11 2024 Pengda Dou <doupengda@loongson.cn> - 41.0.4-3
- [Type] other
- [DESC] add support for loongarch64

* Thu Jan 18 2024 jackeyji <jackeyji@tencent.com> - 41.0.4-2
- fix CVE-2023-49083

* Mon Sep 25 2023 Miaojun Dong <zoedong@tencent.com> - 41.0.4-1
- Bump version to 41.0.4

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 41.0.3-2
- Rebuilt for python 3.11

* Sat Sep 16 2023 Zhao Zhen <jeremiazhao@tencent.com> - 41.0.3-1
- updated upstream 41.0.3
- fixed CVE-2023-23931

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 38.0.2-7
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 18 2023 Wang Guodong <gordonwwang@tencent.com> - 38.0.2-6
- Rebuilt for rust 1.69.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 38.0.2-5
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 38.0.2-4
- Rebuilt for OpenCloudOS Stream 23

* Mon Feb 20 2023 Shuo Wang <abushwang@tencent.com> - 38.0.2-3
- remove unused buildrequires

* Wed Nov  9 2022 Xiaojie Chen <jackxjchen@tencent.com> - 38.0.2-2
- Add requirement cargo and rust

* Tue Nov  1 2022 Xiaojie Chen <jackxjchen@tencent.com> - 38.0.2-1
- Initial build
